FormatItem

Type Alias FormatItem 

pub type FormatItem<'a> = FormatItem<'a>;

Aliased Type

pub enum FormatItem<'a> {
    Literal(&'a [u8]),
    StringLiteral(&'a str),
    Component(Component),
    Compound(&'a [BorrowedFormatItem<'a>]),
    Optional(&'a BorrowedFormatItem<'a>),
    First(&'a [BorrowedFormatItem<'a>]),
}

Variants



Literal(&'a [u8])

👎Deprecated since 0.3.48:

use StringLiteral instead; raw bytes are not recommended

Bytes that are formatted as-is.

Note: These bytes should be UTF-8, but are not required to be. The value is passed through String::from_utf8_lossy when necessary.



StringLiteral(&'a str)

A string that is formatted as-is.



Component(Component)

A minimal representation of a single non-literal item.



Compound(&'a [BorrowedFormatItem<'a>])

A series of literals or components that collectively form a partial or complete description.



Optional(&'a BorrowedFormatItem<'a>)

A FormatItem that may or may not be present when parsing. If parsing fails, there will be no effect on the resulting struct.

This variant has no effect on formatting, as the value is guaranteed to be present.



First(&'a [BorrowedFormatItem<'a>])

A series of FormatItems where, when parsing, the first successful parse is used. When formatting, the first element of the slice is used. An empty slice is a no-op when formatting or parsing.